@@ -5,9 +5,11 @@ use crate::{
   PersonId,
   PersonMentionId,
 };
-use serde::Serialize;
+use serde::{Deserialize, Serialize};
 
-#[derive(Clone, Queryable, Associations, Identifiable, PartialEq, Debug, Serialize)]
+#[derive(
+  Clone, Queryable, Associations, Identifiable, PartialEq, Debug, Serialize, Deserialize,
+)]
 #[belongs_to(Comment)]
 #[table_name = "person_mention"]
 pub struct PersonMention {
